@@ -26,7 +26,17 @@ from tradingkit.pubsub.event.trade import Trade
 
 class BitmexFeeder(Feeder, Publisher):
 
-    def __init__(self, credentials=None, testnet=False, ignore_outdated=True):
+    BITMEX_SYMBOL_MAP = {
+        'BTC/USD': 'XBTUSD',
+        'BTC/USDT': 'XBTUSDT'
+    }
+
+    BITMEX_SYMBOL_MAP_REV = {
+        'XBTUSD': 'BTC/USD',
+        'XBTUSDT': 'BTC/USDT'
+    }
+
+    def __init__(self, symbol='BTC/USD', credentials=None, testnet=False, ignore_outdated=True):
         super().__init__()
         if credentials is not None:
             if ('apiKey' and 'secret') not in credentials:
@@ -34,11 +44,12 @@ class BitmexFeeder(Feeder, Publisher):
         self.credentials = credentials
         self.testnet = testnet
         self.ignore_outdated = ignore_outdated
+        self.symbol = symbol
 
     def on_open(self, ws):
-        self.subscribe(ws, 'trade:XBTUSD')
-        self.subscribe(ws, 'orderBook10:XBTUSD')
-        self.subscribe(ws, 'funding:XBTUSD')
+        self.subscribe(ws, 'trade:%s' % self.BITMEX_SYMBOL_MAP[self.symbol])
+        self.subscribe(ws, 'orderBook10:%s' % self.BITMEX_SYMBOL_MAP[self.symbol])
+        self.subscribe(ws, 'funding:%s' % self.BITMEX_SYMBOL_MAP[self.symbol])
 
         if self.credentials is not None:
             self.authenticate(ws)
@@ -62,57 +73,76 @@ class BitmexFeeder(Feeder, Publisher):
         payload = json.loads(message)
         if 'table' in payload:
             if payload['table'] == 'orderBook10' and payload['data']:
-                order_book = payload['data'][0]
-                order_book['timestamp'] = int(parser.isoparse(payload['data'][0]['timestamp']).timestamp() * 1000)
-                if order_book['symbol'] == 'XBTUSD':
-                    order_book['symbol'] = 'BTC/USD'
-                if self.ignore_outdated:
-                    now_timestamp = time.time() * 1000
-                    diff = abs(order_book['timestamp'] - now_timestamp)
-                    if diff < 1000:
-                        self.dispatch(Book(order_book))
-                else:
+                order_book = self.transform_book_data(payload, self.ignore_outdated)
+                if order_book is not None:
                     self.dispatch(Book(order_book))
+
             elif payload['table'] == 'trade' and payload['data']:
-                trade = payload['data'][0].copy()
-                trade['timestamp'] = parser.isoparse(trade['timestamp']).timestamp() * 1000
-
-                if trade['symbol'] == 'XBTUSD':
-                    trade['symbol'] = 'BTC/USD'
-                trade['amount'] = trade['size']
-                trade['info'] = payload['data'][0].copy()
+                trade = self.transform_trade_data(payload)
                 self.dispatch(Trade(trade))
+
             elif payload['table'] == 'order' and payload['data']:
-
                 if 'ordStatus' in payload['data'][0].keys() and payload['data'][0]['ordStatus'] == 'Filled':
-                    symbol = "BTC/USD" if payload['data'][0]['symbol'] == "XBTUSD" else "unknown"  # todo create pairs list conversion
-                    timestamp = int(parser.isoparse(payload['data'][0]['timestamp']).timestamp() * 1000)
-                    logging.debug("PAYLOAD: %s" % str(payload))
+                    order_data = self.transform_order_data(payload)
+                    self.dispatch(Order(order_data))
 
-                    order_payload = {
-                        "info": payload['data'][0].copy(),
-                        "id": payload['data'][0]['orderID'],
-                        "status": payload['data'][0]['ordStatus'].lower(),
-                        "amount": payload['data'][0]['cumQty'],
-                        "timestamp": timestamp,
-                        "lastTradeTimestamp": int(time.time() * 1000),
-                        "symbol": symbol,
-                        "leavesQty": payload['data'][0]['leavesQty']
-                    }
-
-                    # sometimes bitmex order updates doesn't have avgPx
-                    if 'avgPx' in payload['data'][0]:
-                        order_payload["price"] = payload['data'][0]['avgPx']
-                    self.dispatch(Order(order_payload))
             elif payload['table'] == 'position' and payload['data']:
                 self.dispatch(Position(payload['data'][0]))
+
             elif payload['table'] == 'funding' and payload['data']:
                 self.dispatch(Funding(payload['data'][0]))
+
             else:
                 print("Unknown table Message:", str(payload))
         else:
             print("Unknown Message:", str(payload))
 
+    def transform_book_data(self, payload, ignore_outdated):
+        order_book = payload['data'][0]
+        order_book['timestamp'] = int(parser.isoparse(payload['data'][0]['timestamp']).timestamp() * 1000)
+        order_book['symbol'] = self.BITMEX_SYMBOL_MAP_REV[order_book['symbol']]
+
+        if ignore_outdated:
+            now_timestamp = time.time() * 1000
+            diff = abs(order_book['timestamp'] - now_timestamp)
+            if diff < 1000:
+                return order_book
+        else:
+            return order_book
+        return None
+
+    def transform_trade_data(self, payload):
+        trade = payload['data'][0].copy()
+        trade['timestamp'] = parser.isoparse(trade['timestamp']).timestamp() * 1000
+        trade['symbol'] = self.BITMEX_SYMBOL_MAP_REV[trade['symbol']]
+
+        trade['amount'] = trade['size']
+        trade['info'] = payload['data'][0].copy()
+        if 'cost' not in trade.keys():
+            trade['cost'] = float(trade['size']) * float(trade['price'])
+        return trade
+
+    def transform_order_data(self, payload):
+        symbol = self.BITMEX_SYMBOL_MAP_REV[payload['data'][0]['symbol']]
+        timestamp = int(parser.isoparse(payload['data'][0]['timestamp']).timestamp() * 1000)
+        logging.debug("PAYLOAD: %s" % str(payload))
+
+        order_payload = {
+            "info": payload['data'][0].copy(),
+            "id": payload['data'][0]['orderID'],
+            "status": payload['data'][0]['ordStatus'].lower(),
+            "amount": payload['data'][0]['cumQty'],
+            "timestamp": timestamp,
+            "lastTradeTimestamp": int(time.time() * 1000),
+            "symbol": symbol,
+            "leavesQty": payload['data'][0]['leavesQty']
+        }
+
+        # sometimes bitmex order updates doesn't have avgPx
+        if 'avgPx' in payload['data'][0]:
+            order_payload["price"] = payload['data'][0]['avgPx']
+        return order_payload
+
     def on_error(self, ws, error):
         logging.info("[Websocket error] %s" % str(error))
         if isinstance(error, NetworkError):
