@@ -28,10 +28,27 @@ class BridgeExchange(Publisher, Subscriber, Exchange):
         self.peak_balance = 0
         self.max_drawdown = 0
         self.last_price = None
-        self.symbol = None
         self.has_position = True if "bitmex" in str(exchange.__class__) else False
         exchange.seconds()
 
+        self.candles = None
+        self.last_candle = None
+        self.timeframes = {
+            "1m": 60,
+            "5m": 300,
+            "15m": 900,
+            "30m": 1800,
+            "1h": 3600,
+            "4h": 14400,
+            "6h": 21600,
+            "12h": 43200,
+            "1d": 86400,
+            "2d": 172800,
+            "4d": 345600,
+            "1w": 604800,
+            "2w": 1209600
+        }
+
     def sec(self):
         return self.exchange.sec()
 
@@ -69,32 +86,24 @@ class BridgeExchange(Publisher, Subscriber, Exchange):
 
     def on_event(self, event: Event):
         if isinstance(event, Book):
-            if self.last_price is None:
-                self.plot_balances(event.payload['timestamp'], event.payload['symbol'], event.payload['bids'][0][0])
-                self.symbol = event.payload['symbol']
             self.last_price = event.payload['bids'][0][0]
-        if isinstance(event, Candle):
-            self.plot_candle(event)
         if isinstance(event, Order):
             order = event.payload.copy()
             if order['id'] in self.orders_history.keys():
                 self.orders_history[order['id']].update(order)
-            event.payload = self.orders_history[order['id']]
+                event.payload = self.orders_history[order['id']]
             self.plot_order(event)
-            self.plot_balances(order['lastTradeTimestamp'], order['symbol'], self.last_price)
         if isinstance(event, OpenOrder):
             self.plot_order(event)
-            order = event.payload.copy()
-            self.plot_balances(order['timestamp'], order['symbol'], self.last_price)
-        if isinstance(event, Liquidation):
+        if isinstance(event, Trade):
             trade = event.payload
-            self.plot_balances(trade['timestamp'], trade['symbol'], trade['price'])
+            self.candle_dispatcher(trade)
         self.dispatch(event)
 
     def fetch_open_orders(self, symbol=None, since=None, limit=None, params={}):
         return self.exchange.fetch_open_orders(symbol, since, limit, params)
 
-    def create_order(self, symbol, type, amount, side=None, price=None, params={}):
+    def create_order(self, symbol, type, side=None, amount=0, price=None, params={}):
         if amount == 0:
             raise ValueError("Zero order amount is not allowed!!!")
         elif amount < 0 and side is not None:
@@ -152,10 +161,14 @@ class BridgeExchange(Publisher, Subscriber, Exchange):
     def get_max_draw_down(self):
         return self.max_drawdown
 
+    def getPairs(self, symbol):
+        return symbol
+
     def plot_balances(self, timestamp, symbol, price):
-        balances = self.fetch_balance()['free']
         exchange_date = datetime.fromtimestamp(timestamp / 1000.0).isoformat()
         base, quote = symbol.split('/')
+        all_balances = self.fetch_balance()
+        balances = all_balances['free'] if all_balances['free'][base] else all_balances['total']
 
         base_balance = balances[base] if base in balances else 0
         quote_balance = balances[quote] if quote in balances else 0
@@ -188,8 +201,8 @@ class BridgeExchange(Publisher, Subscriber, Exchange):
                 'x': exchange_date,
                 'y': equity,
                 'base_equity': base_equity,
-                'base_balance': base_balance,
-                'quote_balance': quote_balance,
+                'base_balance': all_balances['total'][base],
+                'quote_balance': all_balances['total'][quote] if quote in all_balances['total'] else 0,
                 'position_vol': position_vol,
                 'position_price': position_price,
                 'invested': base_balance * price,
@@ -237,33 +250,53 @@ class BridgeExchange(Publisher, Subscriber, Exchange):
             'yaxis': 'price',
             'data': candle,
         }))
-        date = datetime.fromisoformat(candle['datetime'])
-        if self.last_balance_check is None or date - self.last_balance_check > timedelta(hours=1):
-            self.last_balance_check = date
-            self.balance_history.append(self.save_current_balance(candle['close']))
 
     def calculate_max_drawdown(self, base_balance, quote_balance):
-        balance = quote_balance if quote_balance > 0 else base_balance
+        if self.last_price:
+            balance = quote_balance + base_balance * self.last_price if quote_balance > 0 else base_balance
 
-        if balance > self.peak_balance:
-            self.peak_balance = balance
+            if balance > self.peak_balance:
+                self.peak_balance = balance
 
-        drawdown = (balance - self.peak_balance) / self.peak_balance
-        self.max_drawdown = min(self.max_drawdown, drawdown)
-
-    def save_current_balance(self, price):
-        balances = self.fetch_balance()['free']
-        base, quote = self.symbol.split('/')
-
-        base_balance = balances[base] if base in balances else 0
-        quote_balance = balances[quote] if quote in balances else 0
-
-        # todo use quote equity for kraken (equity = quote_balance + base_balance * price)
-        base_equity = base_balance + quote_balance / price
-        return base_equity
+            drawdown = (balance - self.peak_balance) / self.peak_balance
+            self.max_drawdown = min(self.max_drawdown, drawdown)
 
     def get_sharpe_ratio(self):
-        standard_desviation = numpy.std(self.balance_history)
-        sharpe_ratio = (self.balance_history[-1] / self.balance_history[0]) / standard_desviation
+        standard_deviation = numpy.std(self.balance_history)
+        sharpe_ratio = (self.balance_history[-1] / self.balance_history[0]) / standard_deviation
         return sharpe_ratio
 
+    def candle_dispatcher(self, trade):
+
+        if self.candles is None:
+            self.candles = {x:{} for x in self.timeframes.keys()}
+
+        if self.last_candle is None:
+            self.last_candle = {x:None for x in self.timeframes.keys()}
+
+        for tf in self.timeframes.keys():
+            sec = self.timeframes[tf]
+            key = trade['timestamp'] // (sec * 1000) * sec
+            key = str(datetime.fromtimestamp(key))
+            if self.last_candle[tf] is not None and key in self.candles[tf]:
+                self.candles[tf][key]['high'] = max(self.candles[tf][key]['high'], trade['price'])
+                self.candles[tf][key]['low'] = min(self.candles[tf][key]['low'], trade['price'])
+                self.candles[tf][key]['close'] = trade['price']
+                self.candles[tf][key]['vol'] += trade['amount']
+                self.candles[tf][key]['cost'] += trade['cost']
+                self.candles[tf][key]['trades'] += 1
+            else:
+                self.candles[tf][key] = {
+                    'datetime': key,
+                    'open': trade['price'],
+                    'high': trade['price'],
+                    'low': trade['price'],
+                    'close': trade['price'],
+                    'vol': trade['amount'],
+                    'cost': trade['cost'],
+                    'trades': 1,
+                    'timeframe': tf
+                }
+                if self.last_candle[tf] is not None:
+                    self.dispatch(Candle(self.last_candle[tf]))
+            self.last_candle[tf] = self.candles[tf][key]
